
# Preferences
## From Python Client
### Default Attributes
prism.get_default_attributes, set_default_attributes 설명
### Package Priorities
Data Component Package Priorities
어떤 Data Component들이 Package Priority를 설정할 수 있는지
prism.get_package_priority, prism.set_package_priority 설명

### ETC
timezone and quiet_mode
prism.set_preference() 설명

## From Web Client
prism.preference_setting()
default attributes, package priorities 설정 설명 추가
